@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::ReadmeAnyFromPod;
 # ABSTRACT: Automatically convert POD to a README in any format for Dist::Zilla
-$Dist::Zilla::Plugin::ReadmeAnyFromPod::VERSION = '0.161150';
+$Dist::Zilla::Plugin::ReadmeAnyFromPod::VERSION = '0.161170';
 use List::Util 1.33 qw( none first );
 use Moose::Util::TypeConstraints qw(enum);
 use Moose;
@@ -274,7 +274,10 @@ sub _get_source_pod {
         $pod_content .= PPI::Token::Pod->merge(@$pod_elems);
     }
 
-    if ((my $encoding = $self->_get_source_encoding) ne 'raw') {
+    if ((my $encoding = $self->_get_source_encoding) ne 'raw'
+            and not eval { Dist::Zilla::Role::PPI->VERSION('6.003') }
+    ) {
+        # older Dist::Zilla::Role::PPI passes encoded content to PPI
         require Encode;
         $pod_content = Encode::decode($encoding, $pod_content);
     }
@@ -335,7 +338,7 @@ Dist::Zilla::Plugin::ReadmeAnyFromPod - Automatically convert POD to a README in
 
 =head1 VERSION
 
-version 0.161150
+version 0.161170
 
 =head1 SYNOPSIS
 
